@@ -10,7 +10,7 @@ class FITestParameter(Base):
     id = Column(Integer, primary_key=True)
     test_id = Column(Integer, ForeignKey('test.id'))
     test = relationship('FITest')
-    name = Column(String)
+    name = Column(String(255), index=True)
     test_parameter_service_id = Column(Integer, ForeignKey('test_parameter_service.id'))
     test_parameter_service = relationship('FITestParameterService')
     test_parameter_context_id = Column(Integer, ForeignKey('test_parameter_context.id'))
